@@ -1586,7 +1586,8 @@ class PreferencesDialog(gtk.Dialog):
             self.connect("row-activated" , self.on_activate)
 
         def set_state(self, entry, state):
-            PluginManager.plugin_settings._gconf.set_bool(entry.key, state)
+            if PluginManager.plugin_settings:
+                PluginManager.plugin_settings._gconf.set_bool(entry.key, state)
 
         def on_activate(self, widget, path, column):
             model = self.get_model()
@@ -1599,21 +1600,22 @@ class PreferencesDialog(gtk.Dialog):
                 self.manager.deactivate(name=bname)
 
         def set_items(self, manager):
-            entries = manager.plugin_settings._gconf.all_entries(PluginManager.plugin_settings._root)
-            store = gtk.ListStore(gobject.TYPE_STRING, gobject.TYPE_BOOLEAN, gobject.TYPE_PYOBJECT)
-            for entry in entries:
-                bname = os.path.basename(entry.key)
-                if manager.plugins.has_key(bname):
-                    # Load the plugin if the plugin is found
-                    module = manager.plugins[bname]
-                    name = "<b>" + module.__plugin_name__ + "</b>"
-                    desc = "\n<small>" + module.__description__ + "</small>"
-                    store.append( [name+desc, False if entry.value is None else entry.value.get_bool(), entry])
-                else:
-                    # Remove the key if no plugin is found
-                    manager.plugin_settings._gconf.unset(entry.key)
-            self.manager = manager
-            self.set_model(store)
+            if manager.plugin_settings:
+                entries = manager.plugin_settings._gconf.all_entries(PluginManager.plugin_settings._root)
+                store = gtk.ListStore(gobject.TYPE_STRING, gobject.TYPE_BOOLEAN, gobject.TYPE_PYOBJECT)
+                for entry in entries:
+                    bname = os.path.basename(entry.key)
+                    if manager.plugins.has_key(bname):
+                        # Load the plugin if the plugin is found
+                        module = manager.plugins[bname]
+                        name = "<b>" + module.__plugin_name__ + "</b>"
+                        desc = "\n<small>" + module.__description__ + "</small>"
+                        store.append( [name+desc, False if entry.value is None else entry.value.get_bool(), entry])
+                    else:
+                        # Remove the key if no plugin is found
+                        manager.plugin_settings._gconf.unset(entry.key)
+                self.manager = manager
+                self.set_model(store)
 
     def __init__(self, parent=None):
         super(PreferencesDialog, self).__init__()
@@ -1642,14 +1644,15 @@ class PreferencesDialog(gtk.Dialog):
         #Configuration page
         vbox = gtk.VBox()
         vbox.set_border_width(5)
-        hbox_tray = gtk.HBox()
-        label = gtk.Label(_("Show icon in system tray"))
-        self.check_button = gtk.CheckButton()
-        self.check_button.set_active(settings.get("tray_icon", False))
-        self.check_button.connect("toggled", self.on_check_toggled)
-        hbox_tray.pack_start(self.check_button,False,False)
-        hbox_tray.pack_start(label, False,False)
-        vbox.pack_start(hbox_tray,False,False)
+        if settings:
+            hbox_tray = gtk.HBox()
+            label = gtk.Label(_("Show icon in system tray"))
+            self.check_button = gtk.CheckButton()
+            self.check_button.set_active(settings.get("tray_icon", False))
+            self.check_button.connect("toggled", self.on_check_toggled)
+            hbox_tray.pack_start(self.check_button,False,False)
+            hbox_tray.pack_start(label, False,False)
+            vbox.pack_start(hbox_tray,False,False)
         notebook.append_page(vbox, gtk.Label( _("Configuration")))
 
         self.connect("delete-event", lambda *args: (True, self.hide())[0])
